@@ -414,6 +414,13 @@ class LibUsbAdaptor {
   static bool CheckProduct(const std::string &expected,
                            const DeviceInformation &device_info);
 
+  /**
+   * @brief Check if this platform supports hotplug.
+   * @returns true if hotplug is supported and enabled on this platform, false
+   *   otherwise.
+   */
+  static bool HotplugSupported();
+
   /**
    * @brief Try and convert an error code to a string
    * @param error_code The error code.
